@@ -271,7 +271,7 @@ impl Drop for Decompressor {
 
 /// Compression level used by a [`Compressor`](struct.Compressor.html)
 /// instance.
-#[derive(Copy, Clone, PartialEq, Eq, Debug)]
+#[derive(Copy, Clone, Debug, PartialEq, Eq, PartialOrd, Ord)]
 pub struct CompressionLvl(i32);
 
 /// Errors that can be returned when attempting to create a
@@ -354,6 +354,18 @@ impl Iterator for CompressionLvlIter {
     }
 }
 
+impl From<CompressionLvl> for i32 {
+    fn from(level: CompressionLvl) -> Self {
+        level.0
+    }
+}
+
+impl From<&CompressionLvl> for i32 {
+    fn from(level: &CompressionLvl) -> Self {
+        level.0
+    }
+}
+
 /// An error that may be returned when calling one of the
 /// [`Compressor`](struct.Compressor.html)'s `compress_*` methods.
 #[derive(Debug, PartialEq)]
@@ -361,6 +373,16 @@ pub enum CompressionError {
     InsufficientSpace,
 }
 
+impl fmt::Display for CompressionError {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match &self {
+            CompressionError::InsufficientSpace => write!(f, "the output buffer provided to a libdeflater *_compress function call was too small for the input data"),
+        }
+    }
+}
+
+impl Error for CompressionError {}
+
 type CompressionResult<T> = std::result::Result<T, CompressionError>;
 
 /// A `libdeflate` compressor that can compress arbitrary data into
